import React from 'react';
import sinon from 'sinon';
import {shallow, mount} from 'enzyme';

import CompatCard from './CompatCard';

describe('Testing CompatCard', () => {

  const compartCardProps = {
    id: 1,
    title: 'title',
    image: 'image',
    subtitle: 'subtitle',
    contentTitle: 'contentTitle',
    contentText: 'contentText',
    primaryText: 'primaryText',
    secondaryText: 'secondaryText'
  }

  it('should render with props', () => {
    const wrapper = mount(<CompatCard {...compartCardProps} />);

    expect('id' in wrapper.props()).toBe(true);
    expect('title' in wrapper.props()).toBe(true);
    expect('image' in wrapper.props()).toBe(true);
    expect('subtitle' in wrapper.props()).toBe(true);
    expect('contentTitle' in wrapper.props()).toBe(true);
    expect('contentText' in wrapper.props()).toBe(true);
    expect('primaryText' in wrapper.props()).toBe(true);
    expect('secondaryText' in wrapper.props()).toBe(true);
  });

  it('should select card', () => {
      const onSelect = sinon.spy();
      const wrapper = shallow(
        <CompatCard
         {...compartCardProps}
         onSelect={onSelect}
        />
      );

      wrapper.find('.card__container').simulate('click');
      expect(onSelect.calledOnce).toBe(true);
  });

  it('should select footer button', () => {
      const onFooterclick = sinon.spy();
      const wrapper = shallow(
        <CompatCard
          {...compartCardProps}
          footerButtonLabel="open"
          onFooterButtonClick={onFooterclick}
        />
      );

      wrapper.find('.card__footer').simulate('click');
      expect(onFooterclick.calledOnce).toBe(true);
  });

  it('should select header button', () => {
      const onHeaderclick = sinon.spy();
      const wrapper = shallow(
        <CompatCard
          {...compartCardProps}
          headerButton={<button type="button">add</button>}
          onHeaderButtonClick={onHeaderclick}
        />
      );

      wrapper.find('.card__header_button').simulate('click');
      expect(onHeaderclick.calledOnce).toBe(true);
  });
});
